xncml Documentation
===================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   tutorial
   contributing
   releasing
   authors
   changelog

.. toctree::
   :maxdepth: 1
   :caption: API Reference:

   apidoc/modules

`xncml` adds NcML support to xarray. It includes utilities to modify NcML documents, and open NcML files as `xarray.Dataset`.
For more information on NcML, take a look at `tutorials and examples <https://docs.unidata.ucar.edu/netcdf-java/current/userguide/basic_ncml_tutorial.html>`_
and the `annotated schema <https://docs.unidata.ucar.edu/netcdf-java/current/userguide/annotated_ncml_schema.html>`_.

Note the existence of a similar `project <https://github.com/ioos/ncml>`_ to edit NcML documents, now archived.

Feedback
========

If you encounter any errors or problems with **xncml**,please open an Issue at the `GitHub main repository <http://github.com/xarray-contrib/xncml>`_.

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
